% demoDetuneFP
%   this function demonstrates the use of tickle with optFP
%

function respDARM_LCGT
  cd ../Optickle;
  path(pathdef)
  addpath(genpath(pwd))
  cd ../Optickle_new
  
  % create the model
  opt = optLCGT;
  
  % get some drive indexes
  nEX = getDriveIndex(opt, 'EX');
  nEY = getDriveIndex(opt, 'EY');

  % get some probe indexes
  nAS_DC = getProbeNum(opt, 'AS_DC');
  nAS_I1 = getProbeNum(opt, 'AS_I');
  nAS_Q1 = getProbeNum(opt, 'AS_Q');
  nPR_DC = getProbeNum(opt, 'PR_DC');
  nIX_DC = getProbeNum(opt, 'IX_DC');
  nEX_DC = getProbeNum(opt, 'EX_DC');

  
  
  % compute the DC signals and TFs on resonances
  f = logspace(-1, 4, 200)';
  [fDC, sigDC0, sigAC0, mMech0, noiseAC0] = tickle(opt, [], f);

  % compute the same a little off resonance
  pos = zeros(opt.Ndrive, 1);
  pos(nEX) = 0.005e-12;
  pos(nEY) = -0.005e-12;
  [fDC1, sigDC1, sigAC1, mMech1, noiseAC1] = tickle(opt, pos, f);

  
  
  % make a response plot
  hXI = getTF(sigAC0, nAS_I1, nEX);
  hYI = getTF(sigAC0, nAS_I1, nEY);
  hXQ = getTF(sigAC0, nAS_Q1, nEX);
  hYQ = getTF(sigAC0, nAS_Q1, nEY);
  hX = getTF(sigAC1, nAS_DC, nEX);
  hY = getTF(sigAC1, nAS_DC, nEY);

  hDARM = (hY - hX)/2;

  demph = (-90)*pi/180;
  hDARMRF = (hXI - hYI)/2 * cos(demph) + (hXQ - hYQ)/2 * sin(demph);
    
  % make a noise plot
  n0 = sqrt((noiseAC0(nAS_I1, :)'.^2 + noiseAC0(nAS_Q1, :)'.^2)/2);
  n1 = noiseAC1(nAS_DC, :)';
  
  figure(1)
  loglog(f, abs([abs(hDARM), abs(hDARMRF)]))
  xlabel('Hz')
  ylabel('W/m')
  legend('DC', 'RF');

  
  figure(2)
  loglog(f, abs([n1, n0]))
  xlabel('Hz')
  ylabel('W/rHz')
  legend('DC', 'RF');
  
  
  figure(3)
  loglog(f, [abs(n1 ./ hDARM), abs(n0 ./ hDARMRF)])
  xlabel('Hz')
  ylabel('m/rtHz')
  title('Quantum Noise Limit for Detuned Cavity', 'fontsize', 18);
  legend('DC', 'RF');
  grid on
  
  dsave = [f, abs(n1 ./ hDARM), abs(n0 ./ hDARMRF)];
  save data.dat dsave -ASCII;