% Display the DARM loop and a few noises.
%
% [sigDC, sigAC, mechTF] = respDARM(f, sigAC, mechTF)
% f - frequency vector for plots
% sigAC and mechTF - from compute
%
% This is an EXAMPLE loop for DARM and some noise projections.  The loop
% is certainly not good, and the noise projections are almost certainly
% wrong, but this should show how Optickle can be used.
%
% Example:
% f = logspace(0, 4, 1000)';
% opt = optLCGT;
% [sigDC, sigAC, mechTF, fDC] = compute(opt, [], f);
% respDARM(opt, f, sigAC, mechTF, fDC);

function respDARM()

  cd ../;
  addpath(pwd)
  cd LCGT;
  
  opt = optLCGT;
  f = logspace(-1, 4, 75)';
  [sigDC, sigAC, mechTF, fDC] = compute(opt, [], f);
  
%   %pos = zeros(opt.Ndrive, 1);
%   pos = zeros(opt.Noptic, 1);
   nEX = getDriveIndex(opt, 'EX');
   nEY = getDriveIndex(opt, 'EY');
%   
%   pos(nEX) = 1.5e-12;
%   pos(nEY) = -1.5e-12;
%   [sigDC1, sigAC1, mechTF1, fDC1] = compute(opt, pos, f);
% 
  
  % probe names and numbers
  oprb = opt.probe;
  prbNames = {oprb.name};

  % some parameters
  wE = 2 * pi * 0.7;			% resonance of end mirror (rad/s)
  mE = 40;				% mass of end mirror (kg)
  gAct = 1e-6;				% actuator DC gain (m/V)
  gSensor = 1;				% sensor DC gain (V/W)
  fUGF = 200;				% unity gain of servo (Hz)
  nSigI = strmatch('AS I1', prbNames);	% which signal to use
  nSigQ = strmatch('AS Q1', prbNames);	% which signal to use
  nSig = strmatch('AS DC', prbNames);	% which signal to use

  nAS = getFieldAt(opt, 'AS', 'in');
  
  % ==== Optical transfer functions
  % hSens is from mirror position to sensor signal (W/m)
  hAXI = squeeze(sigAC(nSigI, nEX, :));
  hAYI = squeeze(sigAC(nSigI, nEY, :));
  
  hAXQ = squeeze(sigAC(nSigQ, nEX, :));
  hAYQ = squeeze(sigAC(nSigQ, nEY, :));

  
  
  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % DARM sweep
  
  % prepare some variables
  nAS1 = strmatch('AS', prbNames);
  pos = zeros(opt.Noptic, 1);

  pos(nEX) = 3e-11;
  pos(nEY) = -3e-11;
  
  [xPos, sigDC2, fDC2] = sweepDC(opt, -pos, pos, 1000);

  % Get sensing matrix elements and determine phase error in REFL1
  %   First point just below resonance
  noob = max(find(xPos(nEX,:) < 0));
  slopeAS = sigDC2(nAS1(2:end),noob+1)-sigDC2(nAS1(2:end),noob);
  % divide slope by the ETM motion to get derivative
  smAS = slopeAS / (xPos(nEX,noob+1) - xPos(nEX,noob));
  
  % Phase error
  purr = 180/pi * atan2(smAS(2), smAS(1));

  % Get the digital phase now and add the error to it
  gphase = opt.probe(nAS1(2)).phase + purr;
  
  if abs(purr) > 0.3
    disp('  ')
    disp(['Change AS1 phase to: ' num2str(gphase)])
    disp('  ')
  end

  
  
  
  demph = (136.5)*pi/180;
  
  hSigDARM = ((hAXI - hAYI)/2 * cos(demph) + (hAXQ - hAYQ)/2 * sin(demph))*sqrt(2);

  
%   hAX = squeeze(sigAC1(nSig, nEX, :));
%   hAY = squeeze(sigAC1(nSig, nEY, :));

    
  % === Noise propagation to the error point

  % a flat "shot" noise
  % see also Buonanno & Chen gr-qc/0102012
  %   http://www.iop.org/EJ/article/0264-9381/18/15/102/q115l2.html
  % or Bench
  %   http://www.its.caltech.edu/~rana/aLIGO/Bench/bench33.m

  Phv = 2 * opt.h * opt.c / opt.lambda;
%  Pas = sum(abs(fDC(nAS, :)).^2);
  Pas = sum(abs(fDC(nAS, :).^2));
  %Pas = sum(abs(fDC(nAS, :)))^2;
  aSensorDARM = sqrt(Phv * Pas) * abs(1 ./ hSigDARM);
  
  
figure(101)  
  loglog(f, aSensorDARM);
  title('1/SNR to RF readout')
  xlabel('Hz')
  ylabel('m/rtHz')
  grid on

  
  dsave = [f, aSensorDARM];
  save data_RF.dat dsave -ASCII;

  figure(102)  
  loglog(f, abs(hSigDARM));
grid on