% Display the DARM loop and a few noises.
%
% [sigDC, sigAC, mechTF] = respDARM(f, sigAC, mechTF)
% f - frequency vector for plots
% sigAC and mechTF - from compute
%
% This is an EXAMPLE loop for DARM and some noise projections.  The loop
% is certainly not good, and the noise projections are almost certainly
% wrong, but this should show how Optickle can be used.
%
% Example:
% f = logspace(0, 4, 1000)';
% opt = optLCGT;
% [sigDC, sigAC, mechTF, fDC] = compute(opt, [], f);
% respDARM(opt, f, sigAC, mechTF, fDC);

function respDARM()

  cd ../;
  addpath(pwd)
  cd LCGT;
  
  opt = optLCGT_DC;
  f = logspace(-1, 4, 75)';
  [sigDC, sigAC, mechTF, fDC] = compute(opt, [], f);
  
%   %pos = zeros(opt.Ndrive, 1);
%   pos = zeros(opt.Noptic, 1);
   nEX = getDriveIndex(opt, 'EX');
   nEY = getDriveIndex(opt, 'EY');
%   
%   pos(nEX) = 1.5e-12;
%   pos(nEY) = -1.5e-12;
%   [sigDC1, sigAC1, mechTF1, fDC1] = compute(opt, pos, f);

  
  % probe names and numbers
  oprb = opt.probe;
  prbNames = {oprb.name};

  % some parameters
  wE = 2 * pi * 0.7;			% resonance of end mirror (rad/s)
  mE = 40;				% mass of end mirror (kg)
  gAct = 1e-6;				% actuator DC gain (m/V)
  gSensor = 1;				% sensor DC gain (V/W)
  fUGF = 200;				% unity gain of servo (Hz)
%   nSigI = strmatch('AS I1', prbNames);	% which signal to use
%   nSigQ = strmatch('AS Q1', prbNames);	% which signal to use
  nSig = strmatch('AS DC', prbNames);	% which signal to use

  nAS = getFieldAt(opt, 'AS', 'in');
  
  % ==== Optical transfer functions
  % hSens is from mirror position to sensor signal (W/m)
  
  hAX = squeeze(sigAC(nSig, nEX, :));
  hAY = squeeze(sigAC(nSig, nEY, :));

  hSigDARM = (hAX - hAY)/2;
  

 
  
  % === Noise propagation to the error point

  % a flat "shot" noise
  % see also Buonanno & Chen gr-qc/0102012
  %   http://www.iop.org/EJ/article/0264-9381/18/15/102/q115l2.html
  % or Bench
  %   http://www.its.caltech.edu/~rana/aLIGO/Bench/bench33.m

  Phv = 2 * opt.h * opt.c / opt.lambda;
  Pas = sum(abs(fDC(nAS, :)).^2);
  aSensorDARM = sqrt(Phv * Pas) * abs(1 ./ hSigDARM);
  
  
figure(101)  
  loglog(f, aSensorDARM);
  title('1/SNR to DC readout')
  xlabel('Hz')
  ylabel('m/rtHz')
%  legend('1', '2')
  a0 = axis;
  a0(3:4) = [1e19 1e25];
%  axis(a0);
  grid on

  
  dsave = [f, aSensorDARM];
  save data_DC.dat dsave -ASCII;

  figure(102)  
  loglog(f, abs(hSigDARM));
grid on